==> lein-template-0.1.2.jar: META-INF/leiningen/nrepl-figwheel-node/lein-template/README.md <==
# nrepl-figwheel-node-template

A ClojureScript Node.js template for use with [lein-figwheel][] on nREPL.
It was derived from
[mayln/figwheel-node-template]
(https://github.com/malyn/figwheel-node-template).

[lein-figwheel]: https://github.com/bhauman/lein-figwheel

The template sets up a project with both development (`dev`) and
production (`prod`) targets.  The development target includes the
Figwheel auto-builder and code loader.  The production target produces a
standalone `server.js` file for use with the `node` executable (no Java
or ClojureScript dependencies required).


## Usage

* Run the following to create a project:

```sh
$ lein new nrepl-figwheel-node hello-world
$ cd hello-world
$ npm install
```

* Start `lein repl` on a shell or `cider-jack-in` in clojure. Or, you could
just execute `lein figwheel` to get a plain figwheel repl.
* Invoke `(launch-figwheel-nrepl)` on REPL.
* Start Node.js in another terminal window:

```sh
$ node target/server_dev/hello_world.js
```

* Changes to your source files will trigger incremental compilation.  See
the [Figwheel docs][] for more information.

[Figwheel docs]: https://github.com/bhauman/lein-figwheel

## Production

Ready to produce a standalone `.js` file for use with Node.js, perhaps
as part of a Heroku or Azure Websites deployment?

```sh
$ lein cljsbuild once prod
```

The above command generates a `server.js` file in your project
directory.  You can then ship the entire project directory to your web
server, PaaS host, etc.  Note that Heroku looks for a Node.js app before
it looks for a Clojure app, so you can safely leave the `project.clj`
file in place as part of the deployment.


## FAQ

**Where's [lein-npm][]?**

Hosting providers like Heroku and Azure expect to see a `package.json`
file, which lein-npm purposefully hides in order to provide better
integration with Leiningen.  Forcing the user of this template to create
and manage their own `package.json` file means that the resulting
project directory is immediately compatible with standard Node.js
environments.

[lein-npm]: https://github.com/RyanMcG/lein-npm


## License

Copyright © 2015 Michael Alyn Miller, crocket

Distributed under the Eclipse Public License either version 1.0 or (at
your option) any later version.

==> lein-template-0.1.5.jar: META-INF/leiningen/nrepl-figwheel-node/lein-template/README.md <==
# nrepl-figwheel-node-template

A ClojureScript Node.js template for use with [lein-figwheel][] on nREPL.
It was derived from
[mayln/figwheel-node-template]
(https://github.com/malyn/figwheel-node-template).

[lein-figwheel]: https://github.com/bhauman/lein-figwheel

The template sets up a project with both development (`dev`) and
production (`prod`) targets.  The development target includes the
Figwheel auto-builder and code loader.  The production target produces a
standalone `server.js` file for use with the `node` executable (no Java
or ClojureScript dependencies required).


## Preparation

Run the following to create a project:

```sh
$ lein new nrepl-figwheel-node <<project-name>>
$ cd <<project-name>>
$ npm install
```

## Launching REPL on shell

* `lein repl`

## Launching REPL on emacs

* Install cider and clojure-mode.
* emacs company mode is highly recommended for smooth auto-completion.
* Execute `M-x cider-jack-in`.

## Using figwheel on REPL

* Execute `(launch-figwheel-nrepl)` on REPL.
* Start Node.js in a terminal window:

```sh
$ node target/server_dev/<<project-name>>.js
```

* Changes to your source files will trigger incremental compilation.  See
the [Figwheel docs][] for more information.

[Figwheel docs]: https://github.com/bhauman/lein-figwheel

## Usage on emacs without figwheel

If you don't want to use figwheel, then execute

* `M-x cider-jack-in-clojurescript` in the project.
* Or, `C-c M-J` in a cljs file.

`company mode` is strongly recommended for superb auto-completion.

## Production

Ready to produce a standalone `.js` file for use with Node.js, perhaps
as part of a Heroku or Azure Websites deployment?

```sh
$ lein cljsbuild once prod
```

The above command generates a `server.js` file in your project
directory.  You can then ship the entire project directory to your web
server, PaaS host, etc.  Note that Heroku looks for a Node.js app before
it looks for a Clojure app, so you can safely leave the `project.clj`
file in place as part of the deployment.


## FAQ

**Where's [lein-npm][]?**

Hosting providers like Heroku and Azure expect to see a `package.json`
file, which lein-npm purposefully hides in order to provide better
integration with Leiningen.  Forcing the user of this template to create
and manage their own `package.json` file means that the resulting
project directory is immediately compatible with standard Node.js
environments.

[lein-npm]: https://github.com/RyanMcG/lein-npm


## License

Copyright © 2015 Michael Alyn Miller, crocket

Distributed under the Eclipse Public License either version 1.0 or (at
your option) any later version.
